.. _clozapine:

.. raw:: html

    <br>
    <center>

clozapine
=========

.. raw:: html

    </center>
    <br>

Clozapine is een dodelijke stof, zie de bijsluiter van de FDA:

https://drive.google.com/open?id=0BwaFXkZBje4OdnBmS05sQ2dkUEE

deze potentieel dodelijk aandoeningen kan men door toediening van clozapine oplopen:

* neutropenia (tekort witte bloedcellen)
* myocarditis (ontsteking hartspier)
* cardiomyopathy (ook hartspier)
* Hypotension (lage bloeddruk)
* bradycardia (trage hartslag)
* syncope (flauwvallen)
* cardiac carrest (hartstilstand)
* neuroleptic malignant syndrome (NMS)
* constipation (dikke darm verstopping)
* intestinal obstruction (darm problemen)
* fecal impaction (vastzittend stront)
* paralytic ileus (ook voedsel vastzittend in de darm)

Los van bijwerkingen die dodelijk kunnen zijn, kan dit medicijn ook in
dodelijk hoeveelheid toegediend worden. 12,5 mg is als dodelijk genoteerd,
standaard OD is 2.5 gram, sommige overleven boven de 4 gram.

